﻿/**
 A dialog that allows to show a list of previously uploaded files and select previously uploaded file.
*/
PreviouslyUploadedFilesDialogJS = function (fileService, docViewer, openFileHelper, showErrorMessage) {

    var maxWidth = window.innerWidth;
    var maxHeight = window.innerHeight;
    if (maxHeight > 500)
        maxHeight = 500;
    // create the dialog settings
    var dialogSettings = {
        modal: true,
        maxHeight: maxHeight,
        maxWidth: maxWidth,
        title: "Previously uploaded files",
        buttons: [
            {
                text: "OK",
                localizationId: "OkButton",
                click: __okButton_clicked
            },
            {
                text: "Cancel",
                localizationId: "CancelButton",
                click: __cancelButton_clicked
            }
        ]
    };

    // create the dialog
    var _uploadedFilesDialog = new Vintasoft.Imaging.UI.Dialogs.WebUiDialogJS([], { localizationId: "uploadedFilesDialog" }, dialogSettings);

    // add created dialog to the document viewer
    docViewer.get_Items().addItem(_uploadedFilesDialog);



    PreviouslyUploadedFilesDialogJS.prototype.show = function () {
        _uploadedFilesDialog.get_Items().clearItems();

        // create a request for getting information about previously uploaded files
        var request = new Vintasoft.Shared.WebRequestJS("GetUploadedFilesUrl", __showUploadedFilesList, null, { type: 'POST' });
        // send the request
        fileService.sendRequest(request);
    }


    function __okButton_clicked() {
        var selectedInput = document.querySelector('input[name=fileList]:checked');
        if (selectedInput != null) {
            var fileId = selectedInput.value;
            if (fileId != null && fileId != '') {
                try {
                    // open file with authentication
                    docViewer.openFileWithAuthentication(fileId);
                }
                catch (ex) {
                    showErrorMessage(ex.message);
                }
            }
        }
        _uploadedFilesDialog.hide();
    }

    function __cancelButton_clicked() {
        _uploadedFilesDialog.hide();
    }

    /**
     Creates a modal dialog with list of uploaded files and shows the dialog.
     @param {object} data Information about uploaded files.
    */
    function __showUploadedFilesList(data) {
        var files = data.files;
        // the dialog items
        var items = _uploadedFilesDialog.get_Items();
        // if there is NO previously uploaded files
        if (files.length === 0)
            // add label with text "No uploaded files." to the dialog items
            items.addItem(new Vintasoft.Imaging.UI.UIElements.WebUiLabelElementJS({
                "text": "No uploaded files.", localizationId: "noUploadedFilesLabel"
            }));
        // if there is previously uploaded files
        else {
            // for each previously uploaded file
            for (var i = 0; i < files.length; i++) {
                // add label with file information to the dialog items
                items.addItem(new Vintasoft.Imaging.UI.UIElements.WebUiRadioInputJS({ name: "fileList", value: files[i] }));
                items.addItem(new Vintasoft.Imaging.UI.UIElements.WebUiLabelElementJS({ text: files[i] }));
                items.addItem("br");
            }
        }

        // show the dialog
        _uploadedFilesDialog.show();
    }

}
